(function ($, Drupal) {
  Drupal.behaviors.H5PxAPI = {
    attach: function (context, settings) {
      if (context !== window.document) {
        return;
      }

      if (window.H5P && window.H5P.externalDispatcher) {
        var url = settings.lms_h5p.lrs_endpoint;
        var auth = settings.lms_h5p.lrs_auth;
        var registration = settings.lms_h5p.lrs_registration;

        // When the next button is pressed, submit the check button first, so
        // that the xAPI answered event is triggered.
        // @todo: can we trigger an H5P event instead of pressing the button?
        // Or is showing the H5P feedback temporarily a nice feature?
        $('input[data-drupal-selector="edit-submit"]').on('click', function (event) {
          event.preventDefault();
          $(this).off('click');
          var iframe = $('.h5p-iframe').contents();
          $('.h5p-question-check-answer', iframe).click();
          setTimeout(function () {
            $('input[data-drupal-selector="edit-submit"]').click();
          }, 1000);
        });

        H5P.externalDispatcher.on('xAPI', function (event) {
          event.data.statement.context.registration = registration;

          // lrs_xapi only supports the 'passed' and 'failed' verbs, so
          // transform 'answered' to one of those depending on the value of
          // 'success'.
          // @todo: this might benefit from a mapping via Drupal settings if
          // different H5P activity types send different XAPI statement
          // formats. See https://www.drupal.org/project/lms_xapi/issues/3524080
          if (event.data.statement.verb.id === "http://adlnet.gov/expapi/verbs/answered") {
            if (event.data.statement.result.success === true) {
              event.data.statement.verb.id = 'http://adlnet.gov/expapi/verbs/passed';
            }
            if (event.data.statement.result.success === false) {
              event.data.statement.verb.id = 'http://adlnet.gov/expapi/verbs/failed';
            }
          }
          $.ajax({
            method: 'POST',
            url: url,
            dataType: 'json',
            data: JSON.stringify(event.data.statement),
            headers: {
              "Authorization": auth
            },
          });
        });
      }
    }
  };
})(jQuery, Drupal);

