<?php

declare(strict_types=1);

namespace Drupal\lms_h5p\Plugin\ActivityAnswer;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lms\Attribute\ActivityAnswer;
use Drupal\lms\Entity\Answer;
use Drupal\lms\Plugin\ActivityAnswerBase;
use Drupal\lms_xapi\XapiService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use TinCan\Verb;

/**
 * Xapi/TinCan activity plugin.
 */
#[ActivityAnswer(
  id: 'h5p',
  name: new TranslatableMarkup('H5P'),
)]
final class H5P extends ActivityAnswerBase {

  /**
   * The Xapi service.
   */
  protected XapiService $xapi;

  /**
   * Static score storage.
   */
  private ?float $score = NULL;

  /**
   * {@inheritdoc}
   */
  public function injectServices(ContainerInterface $container): void {
    parent::injectServices($container);
    $this->xapi = $container->get(XapiService::class);
  }

  /**
   * {@inheritdoc}
   */
  public function getScore(Answer $answer): float {
    if ($this->score !== NULL) {
      return $this->score;
    }

    $account = $answer->getOwner();
    $activity = $answer->getActivity();
    $cacheable_metadata = new CacheableMetadata();
    $lms_id = $this->xapi->getLmsId($activity, $account, $cacheable_metadata);
    $score = $this->xapi->getScoreFromLrs($lms_id);
    $this->score = $score ?? 0;

    return $this->score;
  }

  /**
   * {@inheritdoc}
   */
  public function evaluatedOnSave(Answer $answer): bool {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function evaluationDisplay(Answer $answer): array {
    $activity = $answer->getActivity();
    $account = $answer->getOwner();
    $cacheable_metadata = new CacheableMetadata();
    $lms_id = $this->xapi->getLmsId($activity, $account, $cacheable_metadata);
    $uuid = $this->xapi->getLrsUuid($lms_id);
    $score = $this->xapi->getScoreFromLrs($lms_id);

    $statement = $this->xapi->getLatestStatementByUuid($uuid);
    if ($statement === NULL) {
      return [];
    }
    $result = $statement->getResult();
    $response = $result->getResponse();

    // @todo: see if it's possible to load the LRS statement back into the H5P
    // activity instead.
    $build['result'] = [
      'label' => [
        '#type' => 'html_tag',
        '#tag' => 'h3',
        '#value' => $this->t('Response'),
      ],
      'response' => [
        '#type' => 'html_tag',
        '#tag' => 'pre',
        '#value' => $response,
      ],
    ];

    return $build;
  }

}
